@@ -13,26 +13,24 @@ import (
 	"syscall"
 	"time"
 
-	"k8s.io/klog"
 	"github.com/google/uuid"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
-
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/client-go/informers"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/kubernetes/scheme"
 	coreclientsetv1 "k8s.io/client-go/kubernetes/typed/core/v1"
-	"k8s.io/client-go/informers"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
 	"k8s.io/client-go/tools/leaderelection"
 	"k8s.io/client-go/tools/leaderelection/resourcelock"
 	"k8s.io/client-go/tools/record"
 	"k8s.io/client-go/util/flowcontrol"
+	"k8s.io/klog"
 
 	clientset "github.com/openshift/client-go/config/clientset/versioned"
 	externalversions "github.com/openshift/client-go/config/informers/externalversions"
-
 	"github.com/openshift/cluster-version-operator/pkg/autoupdate"
 	"github.com/openshift/cluster-version-operator/pkg/cvo"
 	"github.com/openshift/cluster-version-operator/pkg/internal"
@@ -302,9 +300,9 @@ type Context struct {
 	CVO        *cvo.Operator
 	AutoUpdate *autoupdate.Controller
 
-	CVInformerFactory externalversions.SharedInformerFactory
-	CMInformerFactory informers.SharedInformerFactory
-	InformerFactory   externalversions.SharedInformerFactory
+	CVInformerFactory              externalversions.SharedInformerFactory
+	OpenshiftConfigInformerFactory informers.SharedInformerFactory
+	InformerFactory                externalversions.SharedInformerFactory
 }
 
 // NewControllerContext initializes the default Context for the current Options. It does
@@ -316,15 +314,14 @@ func (o *Options) NewControllerContext(cb *ClientBuilder) *Context {
 	cvInformer := externalversions.NewFilteredSharedInformerFactory(client, resyncPeriod(o.ResyncInterval)(), "", func(opts *metav1.ListOptions) {
 		opts.FieldSelector = fmt.Sprintf("metadata.name=%s", o.Name)
 	})
-	cmInformer := informers.NewFilteredSharedInformerFactory(kubeClient, resyncPeriod(o.ResyncInterval)(), internal.ConfigNamespace, func(opts *metav1.ListOptions) {
-		opts.FieldSelector = fmt.Sprintf("metadata.name=%s", internal.InstallerConfigMap)
-	})
+	openshiftConfigInformer := informers.NewSharedInformerFactoryWithOptions(kubeClient, resyncPeriod(o.ResyncInterval)(), informers.WithNamespace(internal.ConfigNamespace))
+
 	sharedInformers := externalversions.NewSharedInformerFactory(client, resyncPeriod(o.ResyncInterval)())
 
 	ctx := &Context{
-		CVInformerFactory: cvInformer,
-		CMInformerFactory: cmInformer,
-		InformerFactory:   sharedInformers,
+		CVInformerFactory:              cvInformer,
+		OpenshiftConfigInformerFactory: openshiftConfigInformer,
+		InformerFactory:                sharedInformers,
 
 		CVO: cvo.New(
 			o.NodeName,
@@ -335,7 +332,8 @@ func (o *Options) NewControllerContext(cb *ClientBuilder) *Context {
 			resyncPeriod(o.ResyncInterval)(),
 			cvInformer.Config().V1().ClusterVersions(),
 			sharedInformers.Config().V1().ClusterOperators(),
-			cmInformer.Core().V1().ConfigMaps(),
+			openshiftConfigInformer.Core().V1().ConfigMaps(),
+			sharedInformers.Config().V1().Proxies(),
 			cb.ClientOrDie(o.Namespace),
 			cb.KubeClientOrDie(o.Namespace, useProtobuf),
 			o.EnableMetrics,
@@ -362,6 +360,6 @@ func (c *Context) Start(ctx context.Context) {
 		go c.AutoUpdate.Run(2, ch)
 	}
 	c.CVInformerFactory.Start(ch)
-	c.CMInformerFactory.Start(ch)
+	c.OpenshiftConfigInformerFactory.Start(ch)
 	c.InformerFactory.Start(ch)
 }
