@@ -14,6 +14,7 @@ import (
 	"reflect"
 	"regexp"
 	"strings"
+	"runtime"
 	"testing"
 	"time"
 
@@ -203,7 +204,7 @@ func TestIntegrationCVO_initializeAndUpgrade(t *testing.T) {
 		t.Fatal(err)
 	}
 	defer func() {
-		if err := client.Config().ClusterVersions().Delete(ns, nil); err != nil {
+		if err := client.ConfigV1().ClusterVersions().Delete(ns, nil); err != nil {
 			t.Logf("failed to delete cluster version %s: %v", ns, err)
 		}
 		if err := kc.Core().Namespaces().Delete(ns, nil); err != nil {
@@ -272,7 +273,7 @@ func TestIntegrationCVO_initializeAndUpgrade(t *testing.T) {
 		t.Fatal(err)
 	}
 	time.Sleep(time.Second)
-	cv, err := client.Config().ClusterVersions().Get(ns, metav1.GetOptions{})
+	cv, err := client.ConfigV1().ClusterVersions().Get(ns, metav1.GetOptions{})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -282,7 +283,7 @@ func TestIntegrationCVO_initializeAndUpgrade(t *testing.T) {
 	verifyReleasePayload(t, kc, ns, "0.0.1", payloadImage1)
 
 	t.Logf("trigger an update to a new version")
-	cv, err = client.Config().ClusterVersions().Patch(ns, types.MergePatchType, []byte(fmt.Sprintf(`{"spec":{"desiredUpdate":{"image":"%s"}}}`, payloadImage2)))
+	cv, err = client.ConfigV1().ClusterVersions().Patch(ns, types.MergePatchType, []byte(fmt.Sprintf(`{"spec":{"desiredUpdate":{"image":"%s"}}}`, payloadImage2)))
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -318,7 +319,7 @@ func TestIntegrationCVO_initializeAndUpgrade(t *testing.T) {
 		t.Fatal(err)
 	}
 	time.Sleep(time.Second)
-	cv, err = client.Config().ClusterVersions().Get(ns, metav1.GetOptions{})
+	cv, err = client.ConfigV1().ClusterVersions().Get(ns, metav1.GetOptions{})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -355,7 +356,7 @@ func TestIntegrationCVO_initializeAndHandleError(t *testing.T) {
 		t.Fatal(err)
 	}
 	defer func() {
-		if err := client.Config().ClusterVersions().Delete(ns, nil); err != nil {
+		if err := client.ConfigV1().ClusterVersions().Delete(ns, nil); err != nil {
 			t.Logf("failed to delete cluster version %s: %v", ns, err)
 		}
 		if err := kc.Core().Namespaces().Delete(ns, nil); err != nil {
@@ -413,7 +414,7 @@ func TestIntegrationCVO_initializeAndHandleError(t *testing.T) {
 	verifyReleasePayload(t, kc, ns, "0.0.1", payloadImage1)
 
 	t.Logf("trigger an update to a new version that should fail")
-	cv, err := client.Config().ClusterVersions().Patch(ns, types.MergePatchType, []byte(fmt.Sprintf(`{"spec":{"desiredUpdate":{"image":"%s"}}}`, payloadImage2)))
+	cv, err := client.ConfigV1().ClusterVersions().Patch(ns, types.MergePatchType, []byte(fmt.Sprintf(`{"spec":{"desiredUpdate":{"image":"%s"}}}`, payloadImage2)))
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -442,7 +443,7 @@ func TestIntegrationCVO_initializeAndHandleError(t *testing.T) {
 	verifyReleasePayloadConfigMap2(t, kc, ns, "0.0.1", payloadImage1)
 
 	t.Logf("switch back to 0.0.1 and verify it succeeds")
-	cv, err = client.Config().ClusterVersions().Patch(ns, types.MergePatchType, []byte(`{"spec":{"desiredUpdate":{"image":"", "version":"0.0.1"}}}`))
+	cv, err = client.ConfigV1().ClusterVersions().Patch(ns, types.MergePatchType, []byte(`{"spec":{"desiredUpdate":{"image":"", "version":"0.0.1"}}}`))
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -483,7 +484,7 @@ func TestIntegrationCVO_gracefulStepDown(t *testing.T) {
 		t.Fatal(err)
 	}
 	defer func() {
-		if err := client.Config().ClusterVersions().Delete(ns, nil); err != nil {
+		if err := client.ConfigV1().ClusterVersions().Delete(ns, nil); err != nil {
 			t.Logf("failed to delete cluster version %s: %v", ns, err)
 		}
 		if err := kc.Core().Namespaces().Delete(ns, nil); err != nil {
@@ -606,7 +607,7 @@ func TestIntegrationCVO_cincinnatiRequest(t *testing.T) {
 		t.Fatal(err)
 	}
 	defer func() {
-		if err := client.Config().ClusterVersions().Delete(ns, nil); err != nil {
+		if err := client.ConfigV1().ClusterVersions().Delete(ns, nil); err != nil {
 			t.Logf("failed to delete cluster version %s: %v", ns, err)
 		}
 		if err := kc.Core().Namespaces().Delete(ns, nil); err != nil {
@@ -694,7 +695,7 @@ metadata:
 		t.Logf("latest version:\n%s", printCV(lastCV))
 		t.Fatal("no request received at upstream URL")
 	}
-	expectedQuery := fmt.Sprintf("channel=test-channel&id=%s&version=0.0.1", id.String())
+	expectedQuery := fmt.Sprintf("arch=%s&channel=test-channel&id=%s&version=0.0.1", runtime.GOARCH, id.String())
 	expectedQueryValues, err := url.ParseQuery(expectedQuery)
 	if err != nil {
 		t.Fatalf("could not parse expected query: %v", err)
@@ -713,7 +714,7 @@ metadata:
 func waitForUpdateAvailable(t *testing.T, client clientset.Interface, ns string, allowIncrementalFailure bool, versions ...string) (*configv1.ClusterVersion, error) {
 	var lastCV *configv1.ClusterVersion
 	return lastCV, wait.PollImmediate(200*time.Millisecond, 60*time.Second, func() (bool, error) {
-		cv, err := client.Config().ClusterVersions().Get(ns, metav1.GetOptions{})
+		cv, err := client.ConfigV1().ClusterVersions().Get(ns, metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return false, nil
 		}
@@ -824,7 +825,7 @@ func waitForUpdateAvailable(t *testing.T, client clientset.Interface, ns string,
 func waitUntilUpgradeFails(t *testing.T, client clientset.Interface, ns string, failingReason, failingMessage, progressingMessage string, versions ...string) (*configv1.ClusterVersion, error) {
 	var lastCV *configv1.ClusterVersion
 	return lastCV, wait.PollImmediate(200*time.Millisecond, 60*time.Second, func() (bool, error) {
-		cv, err := client.Config().ClusterVersions().Get(ns, metav1.GetOptions{})
+		cv, err := client.ConfigV1().ClusterVersions().Get(ns, metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return false, nil
 		}
